tietools.add_or_remove_tie_chain_notes_to_achieve_scaled_written_duration
=========================================================================

.. autofunction:: abjad.tools.tietools.add_or_remove_tie_chain_notes_to_achieve_scaled_written_duration.add_or_remove_tie_chain_notes_to_achieve_scaled_written_duration
